@@ -1,11 +1,11 @@
 import faulthandler
 
-from apronpy.box import PyBox
+from apronpy.box import PyBox, PyBoxMPQManager, PyBoxDManager
+from apronpy.dimension import PyDimChange, DimChange
 from apronpy.environment import PyEnvironment
-from apronpy.interval import PyMPQInterval
+from apronpy.interval import PyMPQInterval, PyDoubleInterval
 from apronpy.lincons0 import ConsTyp
-from apronpy.manager import PyBoxMPQManager, PyPolkaMPQstrictManager
-from apronpy.polka import PyPolka
+from apronpy.polka import PyPolka, PyPolkaMPQstrictManager
 from apronpy.tcons1 import PyTcons1, PyTcons1Array
 from apronpy.texpr0 import TexprOp, TexprRtype, TexprRdir
 from apronpy.texpr1 import PyTexpr1
@@ -13,66 +13,96 @@ from apronpy.var import PyVar
 
 faulthandler.enable()
 
-e = PyEnvironment([
-    PyVar('x1'), PyVar('x2'),
-    PyVar('y1'), PyVar('y2'),
-    PyVar('z1'), PyVar('z2'), PyVar('z3'), PyVar('z4'), PyVar('z5')
-], [])
+from apronpy.var import PyVar
+from apronpy.environment import PyEnvironment
+from apronpy.box import PyBoxMPQManager
+from apronpy.abstract1 import PyAbstract1
+
+env = PyEnvironment([PyVar('x')])
 man = PyBoxMPQManager()
-x1 = PyTexpr1.var(e, PyVar('x1'))
-x2 = PyTexpr1.var(e, PyVar('x2'))
-y1 = PyTexpr1.var(e, PyVar('y1'))
-y2 = PyTexpr1.var(e, PyVar('y2'))
+abs_value = PyAbstract1.top(man, env)
 
-b = PyBox(man, e, variables=[PyVar('x1'), PyVar('x2')], intervals=[PyMPQInterval(0, 1, 1, 1), PyMPQInterval(0, 1, 1, 1)])
-print('x1: ', b.bound_variable(PyVar('x1')))
-print('x2: ', b.bound_variable(PyVar('x2')))
+e1 = PyEnvironment()
+e2 = PyEnvironment([PyVar('x')], [])
 
-b = b.assign(PyVar('y1'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-print('y1: ', b.bound_variable(PyVar('y1')))
+while True:
+    union = e1 | e2
+    # del union
+    # inner = abs_value.environment
+    # del inner
 
-b = b.assign(PyVar('y2'), PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-print('y2: ', b.bound_variable(PyVar('y2')))
+# inner_env_A = abs_value.environment
+# inner_env_B = abs_value.environment
+# inner_env_C = abs_value.environment
+# inner_env_D = abs_value.environment
+#
+# del inner_env_A
+# del inner_env_B
+# del inner_env_C
+# del inner_env_D
 
-b = b.assign(PyVar('z1'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, y1, y2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-print('z1: ', b.bound_variable(PyVar('z1')))
+# e = PyEnvironment([
+#     PyVar('x1'), PyVar('x2'),
+#     PyVar('y1'), PyVar('y2'),
+#     PyVar('z1'), PyVar('z2'), PyVar('z3'), PyVar('z4'), PyVar('z5')
+# ], [])
+# man = PyBoxMPQManager()
+# x1 = PyTexpr1.var(e, PyVar('x1'))
+# x2 = PyTexpr1.var(e, PyVar('x2'))
+# y1 = PyTexpr1.var(e, PyVar('y1'))
+# y2 = PyTexpr1.var(e, PyVar('y2'))
+#
+# b = PyBox(man, e, variables=[PyVar('x1'), PyVar('x2')], intervals=[PyMPQInterval(0, 1, 1, 1), PyMPQInterval(0, 1, 1, 1)])
+# print('x1: ', b.bound_variable(PyVar('x1')))
+# print('x2: ', b.bound_variable(PyVar('x2')))
+#
+# b = b.assign(PyVar('y1'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# print('y1: ', b.bound_variable(PyVar('y1')))
+#
+# b = b.assign(PyVar('y2'), PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# print('y2: ', b.bound_variable(PyVar('y2')))
+#
+# b = b.assign(PyVar('z1'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, y1, y2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# print('z1: ', b.bound_variable(PyVar('z1')))
+#
+# expr1 = PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
+# expr2 = PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, expr1, x1, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
+# expr3 = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, expr2, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
+# b = b.assign(PyVar('z2'), expr3)
+# print('z2: ', b.bound_variable(PyVar('z2')))
+#
+# b = b.assign(PyVar('z3'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x1, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# print('z3: ', b.bound_variable(PyVar('z3')))
+#
+# print()
+#
+# z4 = PyTexpr1.var(e, PyVar('z4'))
+# binop = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, z4, expr3, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
+# cond = PyTcons1.make(binop, ConsTyp.AP_CONS_EQ)
+# b = b.meet(PyTcons1Array([cond]))
+# print('x1: ', b.bound_variable(PyVar('x1')))
+# print('x2: ', b.bound_variable(PyVar('x2')))
+# print('y1: ', b.bound_variable(PyVar('y1')))
+# print('y2: ', b.bound_variable(PyVar('y2')))
+# print('z4: ', b.bound_variable(PyVar('z4')))
+#
+# print()
+#
+# b = b.assign(PyVar('y1'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# b = b.assign(PyVar('y2'), PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# binop = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, y1, PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND), TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
+# cond1 = PyTcons1.make(binop, ConsTyp.AP_CONS_EQ)
+# binop = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, y2, PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND), TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
+# cond2 = PyTcons1.make(binop, ConsTyp.AP_CONS_EQ)
+# b = b.meet(PyTcons1Array([cond1, cond2]))
+# b = b.assign(PyVar('z5'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, y1, y2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
+# print('x1: ', b.bound_variable(PyVar('x1')))
+# print('x2: ', b.bound_variable(PyVar('x2')))
+# print('y1: ', b.bound_variable(PyVar('y1')))
+# print('y2: ', b.bound_variable(PyVar('y2')))
+# print('z4: ', b.bound_variable(PyVar('z4')))
 
-expr1 = PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
-expr2 = PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, expr1, x1, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
-expr3 = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, expr2, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
-b = b.assign(PyVar('z2'), expr3)
-print('z2: ', b.bound_variable(PyVar('z2')))
-
-b = b.assign(PyVar('z3'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x1, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-print('z3: ', b.bound_variable(PyVar('z3')))
-
-print()
-
-z4 = PyTexpr1.var(e, PyVar('z4'))
-binop = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, z4, expr3, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
-cond = PyTcons1.make(binop, ConsTyp.AP_CONS_EQ)
-b = b.meet(PyTcons1Array([cond]))
-print('x1: ', b.bound_variable(PyVar('x1')))
-print('x2: ', b.bound_variable(PyVar('x2')))
-print('y1: ', b.bound_variable(PyVar('y1')))
-print('y2: ', b.bound_variable(PyVar('y2')))
-print('z4: ', b.bound_variable(PyVar('z4')))
-
-print()
-
-b = b.assign(PyVar('y1'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-b = b.assign(PyVar('y2'), PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-binop = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, y1, PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND), TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
-cond1 = PyTcons1.make(binop, ConsTyp.AP_CONS_EQ)
-binop = PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, y2, PyTexpr1.binop(TexprOp.AP_TEXPR_SUB, x1, x2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND), TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND)
-cond2 = PyTcons1.make(binop, ConsTyp.AP_CONS_EQ)
-b = b.meet(PyTcons1Array([cond1, cond2]))
-b = b.assign(PyVar('z5'), PyTexpr1.binop(TexprOp.AP_TEXPR_ADD, y1, y2, TexprRtype.AP_RTYPE_REAL, TexprRdir.AP_RDIR_RND))
-print('x1: ', b.bound_variable(PyVar('x1')))
-print('x2: ', b.bound_variable(PyVar('x2')))
-print('y1: ', b.bound_variable(PyVar('y1')))
-print('y2: ', b.bound_variable(PyVar('y2')))
-print('z4: ', b.bound_variable(PyVar('z4')))
+######
 
 # # libapron.ap_texpr1_print.argtypes = [POINTER(Texpr1)]
 # # libapron.ap_texpr1_print(t.texpr1)
